SummaryPatch

Struct SummaryPatch 

pub struct SummaryPatch(/* private fields */);
This is returned when the current summary patch contains no Copy instructions, OR when you are finished with the Merger.

Implementations

Source

impl SummaryPatch

pub fn write<W: Write>(self, sink: W, max_u_size: Option<usize>) -> Result<W>

Writes the summary patch to a sink.

Arguments
  • sink - The sink to write the summary patch to.
  • max_u_size - The maximum size of the super string U. If None, the default is 256MB. This is used to help determine when new windows are created.
Returns

The sink that was passed in.